#include <iostream>
#include <sstream>
#include <algorithm>
#include <vector>
#include <math.h>
#include <string>
#include <queue>
#include <stack>

using namespace std;

typedef long long ll;

struct pt {
    double x, y;
};
bool cmp(pt a, pt b) {
    return a.x < b.x || a.x == b.x && a.y < b.y;
}
bool cw(pt a, pt b, pt c) {
    return a.x * (b.y - c.y) + b.x * (c.y - a.y) + c.x * (a.y - b.y) < 0;
}
bool ccw(pt a, pt b, pt c) {
    return a.x * (b.y - c.y) + b.x * (c.y - a.y) + c.x * (a.y - b.y) > 0;
}
void convex_hull(vector<pt>& a) {
    if (a.size() == 1) return;
    sort(a.begin(), a.end(), &cmp);
    pt p1 = a[0], p2 = a.back();
    vector<pt> up, down;
    up.push_back(p1);
    down.push_back(p1);
    for (size_t i = 1; i < a.size(); ++i) {
        if (i == a.size() - 1 || cw(p1, a[i], p2)) {
            while (up.size() >= 2 && !cw(up[up.size() - 2], up[up.
                size() - 1], a[i]))
                up.pop_back();
            up.push_back(a[i]);
        }
        if (i == a.size() - 1 || ccw(p1, a[i], p2)) {
            while (down.size() >= 2 && !ccw(down[down.size() - 2],
                down[down.size() - 1], a[i]))
                down.pop_back();
            down.push_back(a[i]);
        }
    }
    a.clear();
    for (size_t i = 0; i < up.size(); ++i)
        a.push_back(up[i]);
    for (size_t i = down.size() - 2; i > 0; --i)
        a.push_back(down[i]);
}

inline int area(pt a, pt b, pt c) {
    return (b.x - a.x) * (c.y - a.y) - (b.y - a.y) * (c.x - a.x);
}
inline bool intersect_1(int a, int b, int c, int d) {
    if (a > b) swap(a, b);
    if (c > d) swap(c, d);
    return max(a, c) <= min(b, d);
}
bool intersect(pt a, pt b, pt c, pt d) {
    return intersect_1(a.x, b.x, c.x, d.x)
        && intersect_1(a.y, b.y, c.y, d.y)
        && area(a, b, c) * area(a, b, d) <= 0
        && area(c, d, a) * area(c, d, b) <= 0;
}

int main() {
    pair<pt, pt> e;
    int n; cin >> n;
    vector<pt> v(n), a;
    for (int i = 0; i < n; ++i) {
        cin >> v[i].x;
        cin >> v[i].y;
    }
    a = v;
    convex_hull(a);
    int r = 3 * n - 3 - (int)a.size();
    vector<pair<pt, pt>> w(0);
    if (r % 2 == 0) {
        cout << 2;
    }
    else {
        cout << 1 << "\n";
        int o = 1, p = 2;
        e.first.x = v[o - 1].x;
        e.first.y = v[o - 1].y;
        e.second.x = v[p - 1].x;
        e.second.y = v[p - 1].y;
        w.push_back(e);
        cout << o << " " << p << "\n";
    }
    while(1) {

        int o, p;
        cin >> o >> p;
        if (o == 0 && p == 0) break;
        e.first.x = v[o - 1].x;
        e.first.y = v[o - 1].y;
        e.second.x = v[p - 1].x;
        e.second.y = v[p - 1].y;
        w.push_back(e);


        int h = 0, u = 1;
        for (int i = 0; i + 1 < n; ++i) {
            for (int j = i + 1; j < n; ++j) {
                u = 1;
                for (int k = 0; k < w.size(); ++k) {
                    if (((v[i].x == w[k].first.x && v[i].y == w[k].first.y) && !(v[j].x == w[k].second.x && v[j].y == w[k].second.y))
                        || ((v[i].x == w[k].second.x && v[i].y == w[k].second.y) && !(v[j].x == w[k].first.x && v[j].y == w[k].first.y))
                        || ((v[j].x == w[k].first.x && v[j].y == w[k].first.y) && !(v[i].x == w[k].second.x && v[i].y == w[k].second.y))
                        || ((v[j].x == w[k].second.x && v[j].y == w[k].second.y) && !(v[i].x == w[k].first.x && v[i].y == w[k].first.y))) {
                        // -_-
                    }
                    else if (intersect(v[i], v[j], w[k].first, w[k].second)) {
                        u = 0;
                    }
                }
                if (u == 1) {
                    cout << i + 1 << " " << j + 1 << endl;
                    e.first = v[i];
                    e.second = v[j];
                    w.push_back(e);
                    h = 1;
                }
                if (h == 1) break;
            }
            if (h == 1) break;
        }
        if (h == 0) break;
    }
}